==> 1.0.3.tar.gz: lib/src/utils/x_mock_image.dart <==
class XMock {
  /// 获取模拟图片.
  static String getImage(
    int width, {
    int? height, //图片高度
    int? id, //具体图片 id,参考 https://picsum.photos/images
    String? seed, //根据 seed 获取固定静态图片
    bool isGray = false, //灰色图片
    int? blur, //毛玻璃效果,数字越大越模糊
    int? random, // 获取相同大小的随机图片,避免缓存
    bool isJpg = false, // 是否为 jpg 后缀
    bool isWebp = false, // 当 isJpg 为 false,用于确定是否 webp 后缀
  }) {
    final base = 'https://picsum.photos';
    var url = '$base/$width';

    if (seed != null) {
      url = '$base/seed/$seed/$width';
    }
    if (id != null) {
      url = '$base/id/$id/$width';
    }

    if (height != null) {
      url += '/$height';
    }
    if (isJpg) {
      url += '.jpg';
    } else {
      if (isWebp) {
        url += '.webp';
      }
    }
    if (isGray) {
      url += '?grayscale';
    }
    if (blur != null) {
      if (url.contains('?')) {
        url += '&blur=$blur';
      } else {
        url += '?blur=$blur';
      }
    }
    if (random != null) {
      if (url.contains('?')) {
        url += '&random=$random';
      } else {
        url += '?random=$random';
      }
    }

    return url;
  }

  /// 获取音频
  static String getVoice({index = 0}) {
    var id;
    switch (index) {
      case 0:
        id = 93477122;
        break;
      case 1:
        id = 90991360;
        break;
      case 2:
        id = 96145895;
        break;
      case 3:
        id = 140162434;
        break;
      default:
        id = 93477122;
    }

    final url = 'http://www.170mv.com/kw/antiserver.kuwo.cn/anti.s?'
        'rid=MUSIC_$id&response=res&format=mp3|aac'
        '&type=convert_url&br=128kmp3&agent=iPhone'
        '&callback=getlink&jpcallback=getlink.mp3';
    return url;
  }

  static String getVideo({index = 1}) {
    var url;
    switch (index) {
      case 0:
        url = 'https://media.w3.org/2010/05/sintel/trailer.mp4';
        break;
      case 1:
        url = 'http://www.w3school.com.cn/example/html5/mov_bbb.mp4';
        break;
      case 2:
        url = 'https://www.w3schools.com/html/movie.mp4';
        break;
      case 3:
        url = 'http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4';
        break;
      case 4:
        url = 'https://player.vimeo.com/external/188350983.sd.mp4?'
            's=0bdf01fb5f5c66e43ddae76f573cef2a7786de64&profile_id=164';
        break;
      case 5:
        url = 'https://player.vimeo.com/external/188355959.sd.mp4?'
            's=e5eea0f749282013db81a7e5cd047c57e066e2b9&profile_id=164';
        break;
      case 6:
        url = 'https://player.vimeo.com/external/188365455.sd.mp4?'
            's=7343acee6a02371b4ffeb25760bcbf4b627ccadd&profile_id=164';
        break;
      case 7:
        url = 'https://player.vimeo.com/external/188421287.sd.mp4?'
            's=bdbf8a61c40502211971571fef384f52fe79dbbe&profile_id=164';
        break;
      default:
        url = 'https://media.w3.org/2010/05/sintel/trailer.mp4';
    }
    return url;
  }
}

==> 1.0.6.tar.gz: lib/src/utils/x_mock_image.dart <==
class XMock {
  /// 获取模拟图片.
  static String getImage(
    int width, {
    int? height, //图片高度
    int? id, //具体图片 id,参考 https://picsum.photos/images
    String? seed, //根据 seed 获取固定静态图片
    bool isGray = false, //灰色图片
    int? blur, //毛玻璃效果,数字越大越模糊
    int? random, // 获取相同大小的随机图片,避免缓存
    bool isJpg = false, // 是否为 jpg 后缀
    bool isWebp = false, // 当 isJpg 为 false,用于确定是否 webp 后缀
  }) {
    const base = 'https://picsum.photos';
    var url = '$base/$width';

    if (seed != null) {
      url = '$base/seed/$seed/$width';
    }
    if (id != null) {
      url = '$base/id/$id/$width';
    }

    if (height != null) {
      url += '/$height';
    }
    if (isJpg) {
      url += '.jpg';
    } else {
      if (isWebp) {
        url += '.webp';
      }
    }
    if (isGray) {
      url += '?grayscale';
    }
    if (blur != null) {
      if (url.contains('?')) {
        url += '&blur=$blur';
      } else {
        url += '?blur=$blur';
      }
    }
    if (random != null) {
      if (url.contains('?')) {
        url += '&random=$random';
      } else {
        url += '?random=$random';
      }
    }

    return url;
  }

  /// 获取音频
  static String getVoice({index = 0}) {
    int id;
    switch (index) {
      case 0:
        id = 93477122;
        break;
      case 1:
        id = 90991360;
        break;
      case 2:
        id = 96145895;
        break;
      case 3:
        id = 140162434;
        break;
      default:
        id = 93477122;
    }

    final url = 'http://www.170mv.com/kw/antiserver.kuwo.cn/anti.s?'
        'rid=MUSIC_$id&response=res&format=mp3|aac'
        '&type=convert_url&br=128kmp3&agent=iPhone'
        '&callback=getlink&jpcallback=getlink.mp3';
    return url;
  }

  static String getVideo({index = 1}) {
    String url;
    switch (index) {
      case 0:
        url = 'https://media.w3.org/2010/05/sintel/trailer.mp4';
        break;
      case 1:
        url = 'http://www.w3school.com.cn/example/html5/mov_bbb.mp4';
        break;
      case 2:
        url = 'https://www.w3schools.com/html/movie.mp4';
        break;
      case 3:
        url = 'http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4';
        break;
      case 4:
        url = 'https://player.vimeo.com/external/188350983.sd.mp4?'
            's=0bdf01fb5f5c66e43ddae76f573cef2a7786de64&profile_id=164';
        break;
      case 5:
        url = 'https://player.vimeo.com/external/188355959.sd.mp4?'
            's=e5eea0f749282013db81a7e5cd047c57e066e2b9&profile_id=164';
        break;
      case 6:
        url = 'https://player.vimeo.com/external/188365455.sd.mp4?'
            's=7343acee6a02371b4ffeb25760bcbf4b627ccadd&profile_id=164';
        break;
      case 7:
        url = 'https://player.vimeo.com/external/188421287.sd.mp4?'
            's=bdbf8a61c40502211971571fef384f52fe79dbbe&profile_id=164';
        break;
      default:
        url = 'https://media.w3.org/2010/05/sintel/trailer.mp4';
    }
    return url;
  }
}
